cradle-plugin-api
This crate acts as the API for developing plugins for cradle
Re-exports
pub use convert::check_results_to_ffi;pub use convert::ffi_event_to_agent_event;pub use convert::ffi_string_array_to_vec;pub use convert::free_ffi_results;pub use convert::free_ffi_string;pub use convert::free_ffi_string_array;pub use convert::string_to_ffi_ptr;pub use convert::strings_to_ffi_array;pub use cradle_hooks;pub use checks::*;pub use ffi::*;pub use log::*;
Modules
- checks
- Main definitions in use by plugins
- convert
- FFI <–> Non-FFI conversion functions
- ffi
- FFI-safe type definitions
- log
- Logging functions for plugins
Macros
- clog
- Helpful macro to simplify basic logging without identification
- paste
- plog
- Logging macro that logs with the plugin name for identification
- register_
plugin - Helper macro to register a plugin Builds up the needed exported functions for the plugin to run
Structs
- Check
Result - Check result struct Each cradle check should return this struct after execution
- Cradle
Mutex - Wrapper around an
Arc<Mutex<T>>type Used to simplify the code a bit
Enums
- Cradle
Error - Error enum in use by the workspace
- Severity
- Check result severity Specifies how severe the check result should be classified as
Constants
- CRADLE_
PLUGIN_ API_ MAJOR - Plugin major API version
- CRADLE_
PLUGIN_ API_ MINOR - Plugin minor API version
- CRADLE_
PLUGIN_ API_ VERSION - Plugin API version
Traits
- Cradle
Plugin - Trait definition for a cradle plugin
Type Aliases
- Cradle
Result - Small
Resultwrapper