PluginResults

Struct PluginResults 

pub struct PluginResults { /* private fields */ }
Result struct for each plugin Specifies the plugin name and a vector of the results

Implementations

Source

impl PluginResults

pub fn new(plugin: &'static str) -> Self

Creates a new PluginResults object

pub fn pass(&mut self, check: &str, msg: impl Into<String>)

Helper to create a passing result check

pub fn warn(&mut self, check: &str, msg: impl Into<String>)

Helper to create a warning result check

pub fn fail(&mut self, check: &str, msg: impl Into<String>)

Helper to create a failure result check

pub fn info(&mut self, check: &str, msg: impl Into<String>)

Helper to create an information result check

pub fn warn_with( &mut self, check: &str, msg: impl Into<String>, details: impl Into<String>, )

Helper to create a warning result check with details

pub fn fail_with( &mut self, check: &str, msg: impl Into<String>, details: impl Into<String>, )

Helper to create a failure result check with details

pub fn push(&mut self, result: CheckResult)

Pushes a result into the array

pub fn take(&mut self) -> Vec<CheckResult>

Takes ownership of the stored results and returns them

pub fn len(&self) -> usize

Returns the length of the inner result array

pub fn is_empty(&self) -> bool

Returns true if the inner results array is empty