pub unsafe fn free_ffi_string(ptr: *mut c_char)Expand description
Frees a string allocated by string_to_ffi_ptr
Safety
ptr must either be null or a pointer returned by string_to_ffi_ptr that has not already
been freed
pub unsafe fn free_ffi_string(ptr: *mut c_char)Frees a string allocated by string_to_ffi_ptr
ptr must either be null or a pointer returned by string_to_ffi_ptr that has not already
been freed