macro_rules! plog {
($plugin:expr, $($arg:tt)*) => { ... };
}Expand description
Logging macro that logs with the plugin name for identification
macro_rules! plog {
($plugin:expr, $($arg:tt)*) => { ... };
}Logging macro that logs with the plugin name for identification