macro_rules! register_plugin {
($plugin_ty:ty) => { ... };
}Expand description
Helper macro to register a plugin Builds up the needed exported functions for the plugin to run
macro_rules! register_plugin {
($plugin_ty:ty) => { ... };
}Helper macro to register a plugin Builds up the needed exported functions for the plugin to run