pub struct PluginResults { /* private fields */ }Expand description
Result struct for each plugin Specifies the plugin name and a vector of the results
Implementations
Sourceimpl PluginResults
impl PluginResults
Sourcepub fn new(plugin: &'static str) -> Self
pub fn new(plugin: &'static str) -> Self
Creates a new PluginResults object
Sourcepub fn pass(&mut self, check: &str, msg: impl Into<String>)
pub fn pass(&mut self, check: &str, msg: impl Into<String>)
Helper to create a passing result check
Sourcepub fn warn(&mut self, check: &str, msg: impl Into<String>)
pub fn warn(&mut self, check: &str, msg: impl Into<String>)
Helper to create a warning result check
Sourcepub fn fail(&mut self, check: &str, msg: impl Into<String>)
pub fn fail(&mut self, check: &str, msg: impl Into<String>)
Helper to create a failure result check
Sourcepub fn info(&mut self, check: &str, msg: impl Into<String>)
pub fn info(&mut self, check: &str, msg: impl Into<String>)
Helper to create an information result check
Sourcepub fn warn_with(
&mut self,
check: &str,
msg: impl Into<String>,
details: impl Into<String>,
)
pub fn warn_with( &mut self, check: &str, msg: impl Into<String>, details: impl Into<String>, )
Helper to create a warning result check with details
Sourcepub fn fail_with(
&mut self,
check: &str,
msg: impl Into<String>,
details: impl Into<String>,
)
pub fn fail_with( &mut self, check: &str, msg: impl Into<String>, details: impl Into<String>, )
Helper to create a failure result check with details
Sourcepub fn push(&mut self, result: CheckResult)
pub fn push(&mut self, result: CheckResult)
Pushes a result into the array
Sourcepub fn take(&mut self) -> Vec<CheckResult>
pub fn take(&mut self) -> Vec<CheckResult>
Takes ownership of the stored results and returns them