register_plugin

Macro register_plugin 

macro_rules! register_plugin {
    ($plugin_ty:ty) => { ... };
}
Helper macro to register a plugin Builds up the needed exported functions for the plugin to run